#
# spec file for package perl-Net-Pcap
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Net-Pcap
Name:           perl-Net-Pcap
Version:        0.21
Release:        1.6
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Interface to the pcap(3) LBL packet capture library
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/C/CO/CORION/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildRequires:  perl
BuildRequires:  perl-macros
%{perl_requires}
# MANUAL BEGIN
BuildRequires:  libpcap-devel
Requires:       perl(Data::Hexdumper)
Requires:       perl(NetPacket)
# MANUAL END

%description
'Net::Pcap' is a Perl binding to the LBL pcap(3) library and its Win32
counterpart, the WinPcap library. Pcap (packet capture) is a portable API
to capture network packet: it allows applications to capture packets at
link-layer, bypassing the normal protocol stack. It also provides features
like kernel-level packet filtering and access to internal statistics.

Common applications include network statistics collection, security
monitoring, network debugging, etc.

%prep
%autosetup  -n %{cpan_name}-%{version}
find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
# MANUAL BEGIN
install -D -m0755 eg/pcapdump "%{buildroot}%{_bindir}/pcapdump"
# MANUAL END
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README
%exclude %{_bindir}/pcapinfo
%exclude %{_bindir}/pcapdump
%exclude %{_mandir}/man1/pcapinfo.1%{?ext_man}

%package -n pcapdump
Summary:        Dump packets from the network
Requires:       %{name} = %{version}

%description -n pcapdump
Command line tool to dump packets from the network.

pcapdump mimics the very basic features of tcpdump(1) and provides a good
example of how to use Net::Pcap.

%package -n pcapinfo
Summary:        Prints detailed information about the network devices
Requires:       %{name} = %{version}

%description -n pcapinfo
pcapinfo prints detailed information about the network devices and Pcap library
available on the current host.

%files -n pcapdump
%{_bindir}/pcapdump

%files -n pcapinfo
%{_bindir}/pcapinfo
%{_mandir}/man1/pcapinfo.1%{?ext_man}

%changelog
* Tue Jan 31 2023 Dirk Stoecker <opensuse@dstoecker.de>
- updated to 0.21
  see /usr/share/doc/packages/perl-Net-Pcap/Changes
  0.21 - 2023-01-19 - Max Maischein (CORION)
    [Configure]
  - Avoid implicit ints during feature probing
    This is required for compatibility with future compilers as (for example)
    Fedora is moving to stricter C compiler versions.
    This is merely a cleanup of the C code probing for Pcap functionality,
    no need to upgrade.
    [Code]
  - use "our" for global variable declaration
  - Don't inherit from Exporter anymore
    This might break modules that rely on Net::Pcap isa Exporter, but that
    was never documented.
  0.20 - 2021-12-17 - Max Maischein (CORION)
    [Bugfixes]
  - CPAN RT #118727 Spelling fixes
    Reported by Gregor Herrmann
* Tue Nov 22 2022 Pedro Monreal <pmonreal@suse.com>
- Add missing dependencies for pcapdump [bsc#1201615]
- Remove patch not applied and not mentioned in the changelog.
  * perl-Net-Pcap-avoid-pcap_rmtauth-redefinition.patch
* Wed Aug 24 2022 Dirk Stoecker <opensuse@dstoecker.de>
- updated to 0.20
  see /usr/share/doc/packages/perl-Net-Pcap/Changes
  0.19 - 2021-11-27 - Max Maischein (CORION)
    [Bugfixes]
  - CPAN RT #127685 Restore compilation with libpcap 1.9+
    This incorporates the RedHat patch from
    https://www.cpan.org/authors/id/S/SR/SREZIC/patches/Net-Pcap-0.18-RT127685-RH1485429.patch
    and guards it with the newly introduced version #define
  - GH #9, CPAN RT #117831 , CPAN RT #125352 Too strict test for
    error message from libpcap
    Fix contributed by KENTNL
* Tue Nov 13 2018 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- Cleaned with spec-cleaner
* Fri Nov  9 2018 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- updated to 0.18
  [Bugfixes]
  - CPAN RT #77807: Net::Pcap is no longer limited to one callback function,
    thanks to a patch by James Rouzier.
  - CPAN RT #55163: Typo in eg/pcapdump (Iain Arnell and Jose Pedro Oliveira).
  - CPAN RT #83842: Typo in Net:Pcap (Xavier Guimard).
  [API]
  - Added pcap_offline_filter() (Martijn Lievaart).
  [Code]
  - use warnings (David Farrell).
  [Documentation]
  - Moved HISTORY from README to main documentation.
  - Rewrote AUTHORS to acknowledge all contributors.
  - Updated copyright years.
  [Tests]
  - Added timeouts to prevent tests from hanging (Patrice Auffret).
  - t/17-lib_version.t: adjust regexp to match Apple builds (David Farrell).
  - t/50-poe-component-pcap.t: small improvments.
  - Added t/50-net-pcap-easy.t to test with Net::Pcap::Easy.
  - Added t/50-anyevent-pcap.t to test with AnyEvent::Pcap.
  - Make t/50-* pass with old versions of Test::More
  [Distribution]
  - Converted the Changes file to CPAN::Changes::Spec format.
  - Makefile.PL: append CCFLAGS to $Config{ccflags} instead of overriding it.
  - Makefile.PL: now dies when libpcap isn't found.
  - Makefile.PL: declare minimum Perl version (David Farrell).
- Removed patch perl-Net-Pcap-fix_libpcap_detection.patch
- Added patch to avoid a redefinition of the pcap_rmtauth struct
  already defined in libpcap >= 1.9.0
  * perl-Net-Pcap-avoid-pcap_rmtauth-redefinition.patch
* Sat Jul 27 2013 coolo@suse.com
- updated to 0.17
  - [BUGFIX] CPAN-RT#43308: Net::Pcap no longer enables immediate
    (unsafe) signals delivery.
  - [BUGFIX] Fix allocated size in pcap_open(), pcap_createsrcstr()
    and pcap_parsesrcstr().
  - [API] Now make the C-like API available by default. Added the
    pcap_perl_settings() function and UNSAFE_SIGNALS pseudo-bloc.
  - [CODE] Replaced all occurrences of safemalloc() with Newx().
  - [CODE] Silenced some warnings.
  - [DOC] Added a long note about Net::Pcap and signals delivery.
  - [DOC] Improved README.
  - [DOC] Mention Net::Pcap::Easy.
  - [TESTS] Fixed t/17-lib_version.t to handle two digits versions.
  - [TESTS] CPAN-RT#44448: Fixed t/17-lib_version.t to handle
    versions from the CVS, thanks to Craig Davison.
  - [TESTS] Refactored t/01-api.t and added checks for the new API.
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Fri Dec 16 2011 pascal.bleser@opensuse.org
- add patch to fix libpcap detection on >= 12.1 (32bit), see bnc#711611
* Wed Mar 23 2011 pascal.bleser@opensuse.org
- initial version (0.16)
